@@ -166,7 +166,7 @@ class Client(Singleton):
     def __put_to_cloud(self, path, bucket, bucket_name, tmp=True, tries=0, ignore_prefix=[]):
         prefix, backend = self._random_pick_backend(ignore_prefix)
         if prefix is None:
-            return False, None
+            return False, '尝试过所有Backend都失败'
         
         ret, e = backend.put(path, bucket, bucket_name, tmp)
         if ret:
@@ -177,16 +177,19 @@ class Client(Singleton):
             return self.__put_to_cloud(path, bucket, bucket_name, tmp, tries+1, ignore_prefix=ignore_prefix)
             
     def put_to_cloud(self, path, bucket, bucket_name, tmp=True, refresh=False):
-        cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
-        cache_data = self.get_cache(cache_key, toObj=False) if not refresh else None
-        if cache_data is None:
-            ret, e = self.__put_to_cloud(path, bucket, bucket_name, tmp)
-            if ret:
-                self.cache(cache_key, e)
+        if os.path.isfile(path):
+            cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
+            cache_data = self.get_cache(cache_key, toObj=False) if not refresh else None
+            if cache_data is None:
+                ret, e = self.__put_to_cloud(path, bucket, bucket_name, tmp)
+                if ret:
+                    self.cache(cache_key, e)
 
-            return ret, e
+                return ret, e
+            else:
+                return True, cache_data
         else:
-            return True, cache_data
+            return False, '文件不存在'
 
     async def __put_to_cloud_async(self, path, bucket, bucket_name, tmp=True, tries=0, ignore_prefix=[]):
         prefix, backend = self._random_pick_backend(ignore_prefix)
@@ -203,15 +206,18 @@ class Client(Singleton):
 
         
     async def put_to_cloud_async(self, path, bucket, bucket_name, tmp=True):
-        cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
-        cache_data = await self.get_cache_async(cache_key, toObj=False)
-        if cache_data is None:
-            ret, e = await self.__put_to_cloud_async(path, bucket, bucket_name, tmp)
-            if ret:
-                await self.cache_async(cache_key, e)
-            return ret, e
+        if os.path.isfile(path):
+            cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
+            cache_data = await self.get_cache_async(cache_key, toObj=False)
+            if cache_data is None:
+                ret, e = await self.__put_to_cloud_async(path, bucket, bucket_name, tmp)
+                if ret:
+                    await self.cache_async(cache_key, e)
+                return ret, e
+            else:
+                return True, cache_data
         else:
-            return True, cache_data
+            return False, '文件不存在'
     
     def get_from_cloud(self, path, url, force_copy=False, min_size=0):
         file_path = self.index_cache.get(url)
