@@ -22,6 +22,8 @@ class MQManager(Singleton):
         if init:
             self._init()
         self._inited = True
+
+        self.connection_locker = asyncio.Lock()
     
     def _init(self):
         self.addr = '{}:{}'.format(self.host, self.port)
@@ -45,23 +47,24 @@ class MQManager(Singleton):
             traceback.print_exc()
 
     async def get_mq_conn(self):
-        if not hasattr(self, 'mq') or self.mq.status.is_closed:
-            self.mq = await open_connection(self.host, self.port)
-        else:
-            if not self.mq.status.is_connected:
-                is_timeout = False
-                t = time.time()
-                while self.mq.status.is_reconnecting:
-                    if time.time() - t > 5:
-                        is_timeout = True
-                        break
-                
-                if self.mq.status.is_connected:
-                    return self.mq
-                
-                if is_timeout:
-                    await self.close_async()
-                    self.mq = await open_connection(self.host, self.port)
+        async with self.connection_locker:
+            if not hasattr(self, 'mq') or self.mq.status.is_closed:
+                self.mq = await open_connection(self.host, self.port)
+            else:
+                if not self.mq.status.is_connected:
+                    is_timeout = False
+                    t = time.time()
+                    while self.mq.status.is_reconnecting:
+                        if time.time() - t > 5:
+                            is_timeout = True
+                            break
+                    
+                    if self.mq.status.is_connected:
+                        return self.mq
+                    
+                    if is_timeout:
+                        await self.close_async()
+                        self.mq = await open_connection(self.host, self.port)
         
         return self.mq
             
